package reversi;


/**
 * Interface, das von jedem Reversispieler implementiert werden muss.
 */
public interface ReversiPlayer
{

    /**
     * Not a stateless player, initialized once.
     */

    /**
     * bergibt dem Spieler seine zugewiesene Farbe und die fr beide Spieler
     * identische Zeitbeschrnkung in Millisekunden. Die Methode wird ein
     * einziges Mal zu Beginn eines Spieles aufgerufen.
     * 
     * @param myColor
     *            Die diesem Spieler von der Arena zugewiesene Farbe der
     *            Spielsteine, entweder GameBoard.RED fr rote Spielsteine oder
     *            GameBoard.GREEN fr grne.
     * 
     * @param timeLimit
     *            Die maximale Zeit, die eine Implementierung des Interfaces fr
     *            das Bearbeiten der Methode nextMove() bentigen darf,
     *            angegeben in Millisekunden.
     */
    public void initialize(int myColor, long timeLimit);

    /**
     * Berechnet auf der Basis des bergebenen Spielfeldes den nchsten
     * Spielzug. Die Methode wird von der Reversi-Arena abwechselnd fr jeden
     * Spieler aufgerufen. Die Methode muss eine Instanz der Klasse Coordinates
     * zurckgegeben, die die Position symbolisiert, an der der nchste
     * Spielstein dieses Spielers platziert werden soll. Falls kein Zug mglich
     * ist muss <code>null</code> zurckgeben werden. Implementierungen, die
     * einen ungltigen Zug zurckliefern oder die fr die Berechnung des Zuges
     * lnger als <code>timeLimit</code> ms bentigen, werden disqualifiziert.
     * 
     * @param gb
     *            Beschreibt die augenblickliche Spielsituation.
     * 
     * @return Einen gltigen Zug, dessen Koordinaten innerhalb der Grenzen des
     *         Spielfeldes liegen, wenn ein Zug mglich ist, sonst
     *         <code>null</code>.
     */
    public Coordinates nextMove(GameBoard gb);

} 
